(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/platform-browser'), require('@angular/router'), require('rxjs/add/operator/filter'), require('rxjs/add/operator/map')) :
	typeof define === 'function' && define.amd ? define('ng2-meta', ['exports', '@angular/core', '@angular/platform-browser', '@angular/router', 'rxjs/add/operator/filter', 'rxjs/add/operator/map'], factory) :
	(factory((global['ng2-meta'] = {}),global.ng.core,global.ng.platformBrowser,global.ng.router));
}(this, (function (exports,core,platformBrowser,router) { 'use strict';

var META_CONFIG_TOKEN = new core.InjectionToken('meta config');
var isDefined = function (val) { return typeof val !== 'undefined'; };
var MetaService = /** @class */ (function () {
    function MetaService(router$$1, meta, titleService, activatedRoute, metaConfig) {
        var _this = this;
        this.router = router$$1;
        this.meta = meta;
        this.titleService = titleService;
        this.activatedRoute = activatedRoute;
        this.metaConfig = metaConfig;
        this.router.events
            .filter(function (event) { return (event instanceof router.NavigationEnd); })
            .map(function () { return _this._findLastChild(_this.activatedRoute); })
            .subscribe(function (routeData) {
            _this._processRouteMetaTags(routeData.meta);
        });
    }
    MetaService.prototype._findLastChild = function (activatedRoute) {
        var snapshot = activatedRoute.snapshot;
        var child = snapshot.firstChild;
        while (child.firstChild !== null) {
            child = child.firstChild;
        }
        return child.data;
    };
    MetaService.prototype._updateMetaTag = function (tag, value) {
        var prop = 'name';
        if (tag.startsWith("og:")) {
            prop = 'property';
        }
        this.meta.updateTag((_a = {}, _a[prop] = tag, _a.content = value, _a));
        var _a;
    };
    MetaService.prototype._processRouteMetaTags = function (meta) {
        var _this = this;
        if (meta === void 0) { meta = {}; }
        if (meta.disableUpdate) {
            return;
        }
        this.setTitle(meta.title, meta.titleSuffix);
        Object.keys(meta).forEach(function (key) {
            if (key === 'title' || key === 'titleSuffix') {
                return;
            }
            _this.setTag(key, meta[key]);
        });
        Object.keys(this.metaConfig.defaults).forEach(function (key) {
            if (key in meta || key === 'title' || key === 'titleSuffix') {
                return;
            }
            _this.setTag(key, _this.metaConfig.defaults[key]);
        });
    };
    MetaService.prototype.setTitle = function (title, titleSuffix) {
        var titleContent = isDefined(title) ? title : (this.metaConfig.defaults['title'] || '');
        if (this.metaConfig.useTitleSuffix) {
            titleContent += isDefined(titleSuffix) ? titleSuffix : (this.metaConfig.defaults['titleSuffix'] || '');
        }
        this._updateMetaTag('title', titleContent);
        this._updateMetaTag('og:title', titleContent);
        this.titleService.setTitle(titleContent);
        return this;
    };
    MetaService.prototype.setTag = function (tag, value) {
        if (tag === 'title' || tag === 'titleSuffix') {
            throw new Error("Attempt to set " + tag + " through 'setTag': 'title' and 'titleSuffix' are reserved tag names.\n      Please use 'MetaService.setTitle' instead");
        }
        var content = isDefined(value) ? value : (this.metaConfig.defaults[tag] || '');
        this._updateMetaTag(tag, content);
        if (tag === 'description') {
            this._updateMetaTag('og:description', content);
        }
        return this;
    };
    return MetaService;
}());
MetaService.decorators = [
    { type: core.Injectable },
];
MetaService.ctorParameters = function () { return [
    { type: router.Router, },
    { type: platformBrowser.Meta, },
    { type: platformBrowser.Title, },
    { type: router.ActivatedRoute, },
    { type: undefined, decorators: [{ type: core.Inject, args: [META_CONFIG_TOKEN,] },] },
]; };
var MetaModule = /** @class */ (function () {
    function MetaModule(parentModule) {
        if (parentModule) {
            throw new Error('MetaModule is already loaded. Import it in the AppModule only');
        }
    }
    MetaModule.forRoot = function (metaConfig) {
        if (metaConfig === void 0) { metaConfig = { useTitleSuffix: false, defaults: {} }; }
        return {
            ngModule: MetaModule,
            providers: [
                { provide: META_CONFIG_TOKEN, useValue: metaConfig },
                MetaService
            ]
        };
    };
    return MetaModule;
}());
MetaModule.decorators = [
    { type: core.NgModule, args: [{
                imports: [
                    router.RouterModule
                ]
            },] },
];
MetaModule.ctorParameters = function () { return [
    { type: MetaModule, decorators: [{ type: core.Optional }, { type: core.SkipSelf },] },
]; };

exports.MetaService = MetaService;
exports.MetaModule = MetaModule;
exports.ɵa = META_CONFIG_TOKEN;

Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=ng2-meta.umd.js.map
