import { InjectionToken, Inject, Injectable, NgModule, Optional, SkipSelf } from '@angular/core';
import { Title, Meta } from '@angular/platform-browser';
import { Router, NavigationEnd, ActivatedRoute, RouterModule } from '@angular/router';
import 'rxjs/add/operator/filter';
import 'rxjs/add/operator/map';

var META_CONFIG_TOKEN = new InjectionToken('meta config');
var isDefined = function (val) { return typeof val !== 'undefined'; };
var MetaService = /** @class */ (function () {
    function MetaService(router, meta, titleService, activatedRoute, metaConfig) {
        var _this = this;
        this.router = router;
        this.meta = meta;
        this.titleService = titleService;
        this.activatedRoute = activatedRoute;
        this.metaConfig = metaConfig;
        this.router.events
            .filter(function (event) { return (event instanceof NavigationEnd); })
            .map(function () { return _this._findLastChild(_this.activatedRoute); })
            .subscribe(function (routeData) {
            _this._processRouteMetaTags(routeData.meta);
        });
    }
    MetaService.prototype._findLastChild = function (activatedRoute) {
        var snapshot = activatedRoute.snapshot;
        var child = snapshot.firstChild;
        while (child.firstChild !== null) {
            child = child.firstChild;
        }
        return child.data;
    };
    MetaService.prototype._updateMetaTag = function (tag, value) {
        var prop = 'name';
        if (tag.startsWith("og:")) {
            prop = 'property';
        }
        this.meta.updateTag((_a = {}, _a[prop] = tag, _a.content = value, _a));
        var _a;
    };
    MetaService.prototype._processRouteMetaTags = function (meta) {
        var _this = this;
        if (meta === void 0) { meta = {}; }
        if (meta.disableUpdate) {
            return;
        }
        this.setTitle(meta.title, meta.titleSuffix);
        Object.keys(meta).forEach(function (key) {
            if (key === 'title' || key === 'titleSuffix') {
                return;
            }
            _this.setTag(key, meta[key]);
        });
        Object.keys(this.metaConfig.defaults).forEach(function (key) {
            if (key in meta || key === 'title' || key === 'titleSuffix') {
                return;
            }
            _this.setTag(key, _this.metaConfig.defaults[key]);
        });
    };
    MetaService.prototype.setTitle = function (title, titleSuffix) {
        var titleContent = isDefined(title) ? title : (this.metaConfig.defaults['title'] || '');
        if (this.metaConfig.useTitleSuffix) {
            titleContent += isDefined(titleSuffix) ? titleSuffix : (this.metaConfig.defaults['titleSuffix'] || '');
        }
        this._updateMetaTag('title', titleContent);
        this._updateMetaTag('og:title', titleContent);
        this.titleService.setTitle(titleContent);
        return this;
    };
    MetaService.prototype.setTag = function (tag, value) {
        if (tag === 'title' || tag === 'titleSuffix') {
            throw new Error("Attempt to set " + tag + " through 'setTag': 'title' and 'titleSuffix' are reserved tag names.\n      Please use 'MetaService.setTitle' instead");
        }
        var content = isDefined(value) ? value : (this.metaConfig.defaults[tag] || '');
        this._updateMetaTag(tag, content);
        if (tag === 'description') {
            this._updateMetaTag('og:description', content);
        }
        return this;
    };
    return MetaService;
}());
MetaService.decorators = [
    { type: Injectable },
];
MetaService.ctorParameters = function () { return [
    { type: Router, },
    { type: Meta, },
    { type: Title, },
    { type: ActivatedRoute, },
    { type: undefined, decorators: [{ type: Inject, args: [META_CONFIG_TOKEN,] },] },
]; };
var MetaModule = /** @class */ (function () {
    function MetaModule(parentModule) {
        if (parentModule) {
            throw new Error('MetaModule is already loaded. Import it in the AppModule only');
        }
    }
    MetaModule.forRoot = function (metaConfig) {
        if (metaConfig === void 0) { metaConfig = { useTitleSuffix: false, defaults: {} }; }
        return {
            ngModule: MetaModule,
            providers: [
                { provide: META_CONFIG_TOKEN, useValue: metaConfig },
                MetaService
            ]
        };
    };
    return MetaModule;
}());
MetaModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    RouterModule
                ]
            },] },
];
MetaModule.ctorParameters = function () { return [
    { type: MetaModule, decorators: [{ type: Optional }, { type: SkipSelf },] },
]; };

export { MetaService, MetaModule, META_CONFIG_TOKEN as ɵa };
//# sourceMappingURL=ng2-meta.js.map
